@@ -1,8 +1,6 @@
-from functools import reduce
-from operator import add
-
 from .cor import cor
+from .mean_array_summary import mean_array_summary
 
 # x is a numpy array of 3 dimensions, (chain, MC iteration, parameter)
 def mean_cor(x):
-    return reduce(add, map(lambda m: cor(m), x))/len(x)
+    return mean_array_summary(x, cor)
